from util.sql_util import get_insert_columns_and_values


class TestSqlUtil:
    def test_get_insert_columns_and_values(self):
        columns, values = get_insert_columns_and_values({
            "a": "深爱",
            "b": ['1', '2', '3'],
            "c": 5
        })
        assert columns == 'a,b,c'
        print(values)
        assert values == "'深爱','1,2,3',5"



import pymysql
from constants.database_config import HOST_DICT, PASSWD_DICT
ENV = "test"


def get_mpi_connection():
    """
    获取ncpcs_mpi库的连接
    :return: 数据库连接
    """
    return pymysql.connect(host=HOST_DICT[ENV], port=4000, user="root", passwd=PASSWD_DICT[ENV],
                           db="ncpcs_mpi", charset="utf8")


def get_sibling_connection():
    """
    获取ncpcs_sibling库的连接
    :return: 数据库连接
    """
    return pymysql.connect(host=HOST_DICT[ENV], port=4000, user="root", passwd=PASSWD_DICT[ENV],
                           db="ncpcs_sibling", charset="utf8")


def get_medical_data_analyze_connection():
    """
    获取ncpcs_medical_data_analyze库的连接
    :return: 数据库连接
    """
    return pymysql.connect(host=HOST_DICT[ENV], port=4000, user="root", passwd=PASSWD_DICT[ENV],
                           db="ncpcs_medical_data_analyze", charset="utf8")


def get_tumour_stage_connection():
    """
    获取ncpcs_solid_tumour_stage库的连接
    :return: 数据库连接
    """
    return pymysql.connect(host=HOST_DICT[ENV], port=4000, user="root", passwd=PASSWD_DICT[ENV],
                           db="ncpcs_tumour_stage", charset="utf8")


def get_tumor_connection():
    """
    获取ncpcs_solid_tumour_stage库的连接
    :return: 数据库连接
    """
    return pymysql.connect(host=HOST_DICT[ENV], port=4000, user="root", passwd=PASSWD_DICT[ENV],
                           db="ncpcs_tumor", charset="utf8")



class RelationKey:
    def __init__(self, medical_institution_code, medical_record_no, discharge_time):
        self.medical_institution_code = medical_institution_code
        self.medical_record_no = medical_record_no
        self.discharge_time = discharge_time

    def __repr__(self):
        return '<RelationKey [机构代码：%s， 病案号：%s，出院时间：%s]>' % (self.medical_institution_code, self.medical_record_no, self.discharge_time)


import re

from constants.database_config import STORE_BATCH_COUNT


def get_insert_columns_and_values(data):
    def get_insert_columns(columns):
        return ','.join(columns)

    def get_insert_values(values):
        """
        根据values获取insert sql
        :param values:
        :return:
        """
        ans = ''
        for value in values:
            if value is None or value == '':
                ans += "'',"
            elif isinstance(value, str):
                # value = value[:20000]
                value = value.replace("'", "")
                value = value.replace("\\", "\\\\")
                ans += ("'{}',".format(value))
            elif isinstance(value, int):
                ans += ("{},".format(value))
            elif isinstance(value, set) or isinstance(value, list):
                tmp = ''
                for v in value:
                    if v and isinstance(v, str):
                        tmp += (',' + v)
                ans += "'{}',".format(tmp[1:])
        return ans[:len(ans) - 1]

    return get_insert_columns(data.keys()), get_insert_values(data.values())


def store_by_batch(name, data_list, conn, store_func):
    """
    批量保存
    :param name: 任务名称
    :param data_list: 保存对象列表
    :param conn: 数据库连接
    :param store_func: 保存方法
    :return:
    """
    if not data_list:
        return
    size = len(data_list)
    i = 0
    cursor = conn.cursor()
    print(store_by_batch.__name__, "执行{}任务开始, 总计{}条待存储数据".format(name, size))
    while i < size:
        endI = min(i + STORE_BATCH_COUNT, size)
        print(store_by_batch.__name__, "startIndex: {}, endIndex: {}".format(i, endI))
        for data in data_list[i: endI]:
            store_func(data, cursor)
        conn.commit()
        i += STORE_BATCH_COUNT
    cursor.close()
    print(store_by_batch.__name__, "执行{}任务结束".format(name))
